==> BlankOnDev-0.1000.tar.gz: BlankOnDev-0.1000/lib/BlankOnDev/Migration/bazaar2GitHub.pm <==
package BlankOnDev::Migration::bazaar2GitHub;
use strict;
use warnings FATAL => 'all';

# Import Module :
use Term::ReadKey;
use BlankOnDev::Utils::file;

# Version :
require BlankOnDev::Version;
our $VERSION = $BlankOnDev::Version::VERSION;

# Subroutine for option "addpkg" :
# ------------------------------------------------------------------------
sub _addpkg {
}
# Subroutine for option "branch" :
# ------------------------------------------------------------------------
sub _branch {
    my ($self, $home_dir);
}
# Subroutine for option "execute" :
# ------------------------------------------------------------------------
sub _execute {
}
# Subroutine for option "list" :
# ------------------------------------------------------------------------
sub _list {
}
# Subroutine for option "help" :
# ------------------------------------------------------------------------
sub help {
    print "-----" x 10;
    print "\n";
    print "OPTIONS :\n";
    print "\n";
    printf("%-20s %s\n", "config", "Untuk konfigurasi sebelum menggunakan perintah $0");
    printf("%-20s %s\n", "branch", "Untuk download paket dari Bazaar Server");
    printf("%-20s %s\n", "listgit", "Untuk melihat daftar paket yang sudah di masukkan ke git");
    printf("%-20s %s\n", "list", "Untuk melihat daftar paket yang sudah ditambahkan di lokal");
    printf("%-20s %s\n", "addpkg", "Untuk menambahkan daftar paket yang akan di branch dari Bazaar");
    printf("%-20s %s\n", "execute", "Untuk melihat daftar paket yang sudah di masukkan ke git");
    print "\n";
}
1;

==> BlankOnDev-0.1001.tar.gz: BlankOnDev-0.1001/lib/BlankOnDev/Migration/bazaar2GitHub.pm <==
package BlankOnDev::Migration::bazaar2GitHub;
use strict;
use warnings FATAL => 'all';

# Import Module :
use Term::ReadKey;
use BlankOnDev::Utils::file;

# Version :
require BlankOnDev::Version;
our $VERSION = $BlankOnDev::Version::VERSION;

# Subroutine for option "addpkg" :
# ------------------------------------------------------------------------
sub _addpkg {
}
# Subroutine for option "branch" :
# ------------------------------------------------------------------------
sub _branch {
    my ($self, $home_dir) = @_;
}
# Subroutine for option "execute" :
# ------------------------------------------------------------------------
sub _execute {
}
# Subroutine for option "list" :
# ------------------------------------------------------------------------
sub _list {
}
# Subroutine for option "gitcheck :
# ------------------------------------------------------------------------
sub _git_check {
}
# Subroutine for option "help" :
# ------------------------------------------------------------------------
sub help {
    print "-----" x 10;
    print "\n";
    print "OPTIONS :\n";
    print "\n";
    printf("%-20s %s\n", "config", "Untuk konfigurasi sebelum menggunakan perintah $0");
    printf("%-20s %s\n", "branch", "Untuk download paket dari Bazaar Server");
    printf("%-20s %s\n", "listgit", "Untuk melihat daftar paket yang sudah di masukkan ke git");
    printf("%-20s %s\n", "list", "Untuk melihat daftar paket yang sudah ditambahkan di lokal");
    printf("%-20s %s\n", "addpkg", "Untuk menambahkan daftar paket yang akan di branch dari Bazaar");
    printf("%-20s %s\n", "execute", "Untuk melihat daftar paket yang sudah di masukkan ke git");
    print "\n";
}
1;
